@@ -25,7 +25,7 @@ def get_providers():
     ]
 
 
-def setup():
+def setup(search_path: list = None):
     """Load all :term:`Dependency Providers` and start setting up the
     dependencies container.
     """
@@ -34,12 +34,13 @@ def setup():
         return
 
     import ioc
-    for name, module in get_providers():
+    for _, module in get_providers():
         if not hasattr(module, 'setup_ioc'):
             continue
         module.setup_ioc()
 
-    ioc.load_config(IOC_SEARCH_PATH, override=True)
+    search_path = search_path or IOC_SEARCH_PATH
+    ioc.load_config(search_path, override=True)
 
     IS_CONFIGURED = True
 
