@@ -44,6 +44,19 @@ class CallableDependencyAdapter(BaseDependencyAdapter):
     value = marshmallow.fields.Field(required=True)
 
 
+class FileDependencyAdapter(marshmallow.Schema):
+    type = marshmallow.fields.String(validate=marshmallow.validate.OneOf(['file']),
+        required=True)
+    name = marshmallow.fields.String(required=True)
+    path = marshmallow.fields.String(required=True)
+
+    @marshmallow.post_load
+    def resolve(self, params, **kwargs):
+        with open(params.pop('path'), 'rb') as f:
+            params['value'] = f.read()
+        return LiteralDependency(**params)
+
+
 class SymbolDependencyAdapter(marshmallow.Schema):
     type = marshmallow.fields.String(validate=marshmallow.validate.OneOf(['symbol']),
         required=True)
