@@ -1,17 +1,19 @@
 from ioc.loader import import_symbol
 from ioc.exc import UnsatisfiedDependency
-from ioc import provider
+from ioc.provider import Provider
 from ioc.collection import DependencyCollection
 
 
 class SchemaResolver(object):
     """Resolves the dependencies declared in a schema."""
 
+    def __init__(self, provider: Provider):
+        self.provider = provider
+
     def resolve(self, dep):
         """Resolves a dependency `dep` and returns its declared Python
         object.
         """
-
         # If a string value on a dependency starts with a dollar-sign, it is
         # considered to be an environment variable.
         #if isinstance(getattr(dep, 'value', None), str) and dep.value.startswith('$'):
@@ -48,7 +50,7 @@ class SchemaResolver(object):
 
         # Dependency collections are simple lists of dependencies.
         if dep.is_collection():
-            return DependencyCollection(provider, dep.members)
+            return DependencyCollection(self.provider, dep.members)
 
         # In this implementation, nested dependencies MUST be declared
         # in order e.g. if B depends on A, then A has to be already
@@ -56,13 +58,13 @@ class SchemaResolver(object):
         # nested dependencies can not refer to dependencies declared after
         # themselves.
         for name in dep.requires():
-            if not provider.is_satisfied(name):
+            if not self.provider.is_satisfied(name):
                 raise UnsatisfiedDependency(name)
 
         # If the dependency is in injected but does not have a factor,
         # it simply points to an already resolved declaration.
         if dep.is_injected() and not dep.has_factory():
-            return provider.resolve(dep.key)
+            return self.provider.resolve(dep.key)
 
         # Get the factory, positional and keyword arguments, and
         # chained dependencies from the provider.
